==> p5-Alien-wxWidgets-0.62.tgz: libdata/perl5/site_perl/sparc64-openbsd/Alien/wxWidgets/Config/gtk2_gcc.pm <==
package Alien::wxWidgets::Config::gtk2_gcc;

use strict;

our %VALUES;

{
    no strict 'vars';
    %VALUES = %{
$VAR1 = {
          'defines' => '-D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D_IODBC_ -D__WXGTK__ ',
          'link_libraries' => ' -L/usr/local/lib -pthread -L/usr/local/lib -L/usr/X11R6/lib',
          'version' => '2.008012',
          'alien_base' => 'gtk2_gcc',
          'compiler' => 'c++',
          'include_path' => '-I/usr/local/lib/wx/include/gtk2-unicode-release-2.8 -I/usr/local/include ',
          'linker' => 'c++ -shared -fPIC  ',
          'config' => {
                        'toolkit' => 'gtk2',
                        'unicode' => 0,
                        'debug' => 0,
                        'compiler_kind' => 'gcc',
                        'build' => 'multi',
                        'compiler_version' => '3.4',
                        'mslu' => 0
                      },
          'c_flags' => '-pthread ',
          'prefix' => '/usr/local',
          'link_flags' => '',
          '_libraries' => {
                            'net' => {
                                       'link' => '-lwx_base_net',
                                       'dll' => 'libwx_base_net.so.3.0'
                                     },
                            'aui' => {
                                       'dll' => 'libwx_gtk2_aui.so.3.0',
                                       'link' => '-lwx_gtk2_aui'
                                     },
                            'stc' => {
                                       'dll' => 'libwx_gtk2_stc.so.3.0',
                                       'link' => '-lwx_gtk2_stc'
                                     },
                            'html' => {
                                        'link' => '-lwx_gtk2_html',
                                        'dll' => 'libwx_gtk2_html.so.3.0'
                                      },
                            'core' => {
                                        'link' => '-lwx_gtk2_core',
                                        'dll' => 'libwx_gtk2_core.so.3.0'
                                      },
                            'xrc' => {
                                       'link' => '-lwx_gtk2_xrc',
                                       'dll' => 'libwx_gtk2_xrc.so.3.0'
                                     },
                            'richtext' => {
                                            'dll' => 'libwx_gtk2_richtext.so.3.0',
                                            'link' => '-lwx_gtk2_richtext'
                                          },
                            'qa' => {
                                      'dll' => 'libwx_gtk2_qa.so.3.0',
                                      'link' => '-lwx_gtk2_qa'
                                    },
                            'gizmos' => {
                                          'dll' => 'libwx_gtk2_gizmos.so.3.0',
                                          'link' => '-lwx_gtk2_gizmos'
                                        },
                            'fl' => {
                                      'link' => '-lwx_gtk2_fl',
                                      'dll' => 'libwx_gtk2_fl.so.3.0'
                                    },
                            'xml' => {
                                       'dll' => 'libwx_base_xml.so.3.0',
                                       'link' => '-lwx_base_xml'
                                     },
                            'base' => {
                                        'link' => '-lwx_base',
                                        'dll' => 'libwx_base.so.3.0'
                                      },
                            'gl' => {
                                      'dll' => 'libwx_gtk2_gl.so.3.0',
                                      'link' => '-lwx_gtk2_gl'
                                    },
                            'adv' => {
                                       'dll' => 'libwx_gtk2_adv.so.3.0',
                                       'link' => '-lwx_gtk2_adv'
                                     }
                          },
          'alien_package' => 'Alien::wxWidgets::Config::gtk2_gcc'
        };
    };
}

my $key = substr __PACKAGE__, 1 + rindex __PACKAGE__, ':';

sub values { %VALUES, key => $key }

sub config {
   +{ %{$VALUES{config}},
      package       => __PACKAGE__,
      key           => $key,
      version       => $VALUES{version},
      }
}

1;

==> p5-Alien-wxWidgets-0.67p0.tgz: libdata/perl5/site_perl/sparc64-openbsd/Alien/wxWidgets/Config/gtk2_gcc.pm <==
package Alien::wxWidgets::Config::gtk2_gcc;

use strict;

our %VALUES;

{
    no strict 'vars';
    %VALUES = %{
$VAR1 = {
          'linker' => 'c++ -shared -fPIC  ',
          'link_flags' => '',
          '_libraries' => {
                            'base' => {
                                        'dll' => 'libwx_base.so.3.0',
                                        'link' => '-lwx_base'
                                      },
                            'media' => {
                                         'link' => '-lwx_gtk2_media',
                                         'dll' => 'libwx_gtk2_media.so.3.0'
                                       },
                            'richtext' => {
                                            'dll' => 'libwx_gtk2_richtext.so.3.0',
                                            'link' => '-lwx_gtk2_richtext'
                                          },
                            'core' => {
                                        'dll' => 'libwx_gtk2_core.so.3.0',
                                        'link' => '-lwx_gtk2_core'
                                      },
                            'gizmos' => {
                                          'dll' => 'libwx_gtk2_gizmos.so.3.0',
                                          'link' => '-lwx_gtk2_gizmos'
                                        },
                            'xml' => {
                                       'dll' => 'libwx_base_xml.so.3.0',
                                       'link' => '-lwx_base_xml'
                                     },
                            'adv' => {
                                       'link' => '-lwx_gtk2_adv',
                                       'dll' => 'libwx_gtk2_adv.so.3.0'
                                     },
                            'xrc' => {
                                       'link' => '-lwx_gtk2_xrc',
                                       'dll' => 'libwx_gtk2_xrc.so.3.0'
                                     },
                            'html' => {
                                        'link' => '-lwx_gtk2_html',
                                        'dll' => 'libwx_gtk2_html.so.3.0'
                                      },
                            'net' => {
                                       'dll' => 'libwx_base_net.so.3.0',
                                       'link' => '-lwx_base_net'
                                     },
                            'stc' => {
                                       'link' => '-lwx_gtk2_stc',
                                       'dll' => 'libwx_gtk2_stc.so.3.0'
                                     },
                            'fl' => {
                                      'dll' => 'libwx_gtk2_fl.so.3.0',
                                      'link' => '-lwx_gtk2_fl'
                                    },
                            'qa' => {
                                      'dll' => 'libwx_gtk2_qa.so.3.0',
                                      'link' => '-lwx_gtk2_qa'
                                    },
                            'gl' => {
                                      'link' => '-lwx_gtk2_gl',
                                      'dll' => 'libwx_gtk2_gl.so.3.0'
                                    },
                            'aui' => {
                                       'link' => '-lwx_gtk2_aui',
                                       'dll' => 'libwx_gtk2_aui.so.3.0'
                                     }
                          },
          'prefix' => '/usr/local',
          'alien_base' => 'gtk2_gcc',
          'c_flags' => '-pthread ',
          'compiler' => 'c++',
          'include_path' => '-I/usr/local/lib/wx/include/gtk2-unicode-release-2.8 -I/usr/local/include -I/usr/X11R6/include ',
          'config' => {
                        'compiler_version' => '3.4',
                        'mslu' => 0,
                        'toolkit' => 'gtk2',
                        'build' => 'multi',
                        'compiler_kind' => 'gcc',
                        'debug' => 0,
                        'unicode' => 0
                      },
          'defines' => '-D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D_IODBC_ -D__WXGTK__ ',
          'link_libraries' => ' -L/usr/local/lib -pthread -L/usr/local/lib -L/usr/X11R6/lib',
          'version' => '2.008012',
          'alien_package' => 'Alien::wxWidgets::Config::gtk2_gcc'
        };
    };
}

my $key = substr __PACKAGE__, 1 + rindex __PACKAGE__, ':';

sub values { %VALUES, key => $key }

sub config {
   +{ %{$VALUES{config}},
      package       => __PACKAGE__,
      key           => $key,
      version       => $VALUES{version},
      }
}

1;
